10  PROGNAME$ = "ADATEL -- Average Daily Access Time"
20  VERSION$ = "     Elliptical Orbits   Sept 25, 1990"
30 ' The author regrets that he cannot support or respond to questions about this code
40 'Satellite Identification, Etc.
50    SAT$ = "P3D 3 rev / 2 days (Prepared 29 Apr. 1991)"
60    INCLINATION = 63.4349    ' degrees
70    PERIOD = 960          ' minutes
80    ECTY = .677437757#  ' (Eccentricity)
90    ELEVATION = 0    'Satellite above this angle is in range
100   NSEG = 1000              'Number of segments per orbit
110      '
120 'CONSTANTS, CONVERSION FACTORS, FUNCTIONS, ETC.
130      PI = 3.141593
140      RTOD = 180 / PI  'conversion factor, radians --> degrees
150      DTOR = PI / 180  'conversion factor, degrees --> radians
160      RE = 6371  'Mean radius of earth
170      DEF FNARCSIN (Z) = ATN(Z / SQR(1 - Z * Z))
180      DEF FNARCCOS (Z) = PI / 2 - ATN(Z / SQR(1 - Z * Z))
190      ELEV = ELEVATION * DTOR: COSELEV = COS(ELEV)
200      SININCLIN = SIN(INCLINATION * DTOR)
210      SMA = 331.25 * PERIOD ^ (2 / 3)'Semimajor axis
220      LR = SMA * (1 - ECTY * ECTY)  'Latus rectum
230      K1 = SQR((1 - ECTY) / (1 + ECTY))
240      '
250 FOR ARGPERIGEE = 90 TO 270 STEP 10   '    <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
260   AP = ARGPERIGEE * DTOR                                 '               ^
270   'Initialize parameters                                                 ^
280      TI = 0   ' Time (initial) at start of first segment                 ^
290      FOR I = 0 TO 9: TOTTIME(I) = 0: NEXT I              '               ^
300                                                          '               ^
310   FOR SEGG = 1 TO NSEG 'Loop through one orbit (perigee to perigee) <<<  ^
320     F = 2 * PI * SEGG / NSEG'polar angle (perigee to end of segment)  ^  ^
330     FMID = F - PI / NSEG'polar angle (perigee to midpoint of segment) ^  ^
340     THETA = FMID + AP'polar angle (line of nodes to midpoint of seg.) ^  ^
350     IF THETA > 2 * PI THEN THETA = THETA - 2 * PI: GOTO 350'          ^  ^
360     'Calculate height of satellite at midpoint of segment (H)         ^  ^
370          H = LR / (1 + ECTY * COS(FMID)) - RE' Height                 ^  ^
380     'Calculate Beta (Surface distance in radians between ground       ^  ^
390             ' station and elevation circle)                           ^  ^
400          BETA = FNARCCOS(COSELEV * RE / (RE + H)) - ELEV '            ^  ^
410          COSBETA = COS(BETA)                             '            ^  ^
420     'Calculate time from perigee at end of segment (TF)  '            ^  ^
430          IF SEGG = NSEG THEN TF = PERIOD: GOTO 480       '            ^  ^
440          'Calculate Eccentric Anomaly at end of segment  '            ^  ^
450             EA = 2 * ATN(K1 * TAN(F / 2))                '            ^  ^
460          TF = PERIOD * (EA - ECTY * SIN(EA)) / (2 * PI)  '            ^  ^
470          IF TF < 0 THEN TF = PERIOD + TF                 '            ^  ^
480     'Calculate latitude of SSP at midpoint of segment (SSPLAT)        ^  ^
490          SSPLAT = FNARCSIN(SIN(THETA) * SININCLIN)       '            ^  ^
500                                                          '            ^  ^
510     FOR K = 0 TO 9    'Loop through ground station latitudes   <<<<   ^  ^
520       GSLATITUDE = K * 10 ' ground station latitude in degrees    ^   ^  ^
530       GSLAT = GSLATITUDE * DTOR                          '        ^   ^  ^
540       IF ABS(GSLATITUDE) > 89.9 THEN GSLAT = GSLAT * .9999'       ^   ^  ^
550       GOSUB 690  ' calculate probability factor (P)               ^   ^  ^
560       TOTTIME(K) = TOTTIME(K) + P * (TF - TI)            '        ^   ^  ^
570     NEXT K    '   >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>^   ^  ^
580                                                          '            ^  ^
590     TI = TF                                              '            ^  ^
600   NEXT SEGG    '   >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>^  ^
610                                                          '               ^
620   GOSUB 780 ' Subroutine to print heading                                ^
630   FOR J = 0 TO 9: PRINT J * 10, TOTTIME(J) * 1440 / PERIOD: NEXT J '     ^
640   PRINT : PRINT : PRINT : PRINT : PRINT :                          '     ^
650 NEXT ARGPERIGEE   '    >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>^
660
670 END   'ADATEL    M. Davidoff, K2UBC
680   '
690 'Subroutine to find probability factor for each segment
700      ' logic only covers ground station latitudes >= 0
710    IF SSPLAT > (GSLAT + BETA) THEN P = 0: GOTO 760
720    IF SSPLAT < (GSLAT - BETA) THEN P = 0: GOTO 760
730    IF SSPLAT > PI - (GSLAT + BETA) THEN P = 1: GOTO 760
740    DL = FNARCCOS((COSBETA - SIN(GSLAT) * SIN(SSPLAT)) / (COS(GSLAT) * COS(SSPLAT)))
750    P = DL / PI' Probability of satellite being in range during segment
760 RETURN
770        '
780 'Subroutine to print heading
790    PRINT : PRINT PROGNAME$: PRINT VERSION$: PRINT
800    PRINT SAT$
810    PRINT "     inclination ="; INCLINATION; "degrees"
820    PRINT "     period ="; PERIOD; " minutes"
830    PRINT "     eccentricity ="; ECTY
840    PRINT "     argument of perigee =", ARGPERIGEE; "degrees"
850    PRINT "     elevation cutoff ="; ELEVATION; "degrees"
860    PRINT "     number of segments used ="; NSEG
870    PRINT : PRINT
880    PRINT " Ground        Average      "
890    PRINT " Station       Daily Access "
900    PRINT " (deg N)       Time (min.)  "
910    PRINT
920 RETURN

